@@ -1,20 +1,7 @@
 /*
-   Copyright (c) 2017 Volker Krause <vkrause@kde.org>
+   SPDX-FileCopyrightText: 2017 Volker Krause <vkrause@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef GRAVATAR_HASH_H
@@ -29,8 +16,7 @@ class QByteArray;
 class QString;
 
 namespace Gravatar {
-
-template <int Size> struct UnsignedInt
+template<int Size> struct UnsignedInt
 {
     bool operator<(const UnsignedInt<Size> &other) const
     {
@@ -54,7 +40,9 @@ unsigned int qHash(const Hash &h, unsigned int seed = 0);
 class GRAVATAR_TESTS_EXPORT Hash
 {
 public:
-    enum Type { Invalid, Md5, Sha256 };
+    enum Type {
+        Invalid, Md5, Sha256
+    };
     Hash();
     explicit Hash(const QByteArray &data, Type type);
 
@@ -76,7 +64,6 @@ private:
     } m_hash;
     Type m_type;
 };
-
 }
 
 #endif // GRAVATAR_HASH_H
